<?php
/*
Plugin Name: Image Projector
Plugin URI: http://www.image-projector.com
Description: The unique lightbox and image slider that also let you navigate between posts by image
Version: 2.7
Author: Christian G
Author URI: http://www.lystfotograf.net
License: GPLv2
License URI:  https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: image-projector
Domain Path: /languages

Image Projector os free software: you can redistribute it and/or modify it under the terms of the gnu general public license as published by the free software foundation, either version 2 of the license, or any later version. 

Image projector is distributed in the hope that it will be useful, but without any warranty; without even the implied warranty of merchantability or fitness for a particular purpose. See the gnu general public license for more details.
*/

if (!defined('ABSPATH')) {
	exit("'No direct access available'");
}

if ( ! defined( 'WPIP_VERSION' ) ) {
	define( 'WPIP_VERSION','2.7');
}

$wpip_site_url = site_url();
$wpip_upload_dir = wp_upload_dir();

if ( ! defined( 'WPIP_PLUGIN_URL' ) ) {
	define( 'WPIP_PLUGIN_URL', $wpip_site_url.'/'.PLUGINDIR.'/'. dirname( plugin_basename(__FILE__) ));
}
if ( ! defined( 'WPIP_PLUGIN_DIR' ) )
	define( 'WPIP_PLUGIN_DIR', plugin_dir_path( __FILE__ ));

if ( ! defined( 'WPIP_REF_DIR' ) )
	define( 'WPIP_REF_DIR', WPIP_PLUGIN_DIR.'/admin/ref');

if ( ! defined( 'WPIP_REF_URL' ) ) {
	define( 'WPIP_REF_URL', WPIP_PLUGIN_URL.'/admin/ref');
}

if ( ! defined( 'WPIP_UPLOAD_URL' ) ) {
	define( 'WPIP_UPLOAD_URL', $wpip_upload_dir['baseurl']);
}
if ( ! defined( 'WPIP_UPLOAD_DIR' ) ) {
	
	define( 'WPIP_UPLOAD_DIR', $wpip_upload_dir['basedir']);
}


if( is_admin()) {
	require(WP_PLUGIN_DIR.'/image-projector/includes/ip-settings.php');
} else {

	require(WP_PLUGIN_DIR.'/image-projector/includes/ip-core.php');
}

$wpip_adminopt = get_option( 'image_projector_admin' );
	
if( ! $wpip_adminopt) {
	$wpip_newopt = array('dirty' => false);
	add_option('image_projector_admin', $wpip_newopt);
	update_option('image_projector_admin',$wpip_newopt);
}
// Do on activation
function do_ip_activation () {
			 
	wpiv_check_options();
}
register_activation_hook( __FILE__,'do_ip_activation');


// Check the options
function wpiv_check_options() {


	$ipopt = get_option( 'image_projector_settings', array() );

	if( empty($ipopt)) { // not found, new installation


				// so then go ahead and define the settings array
				$ipopt['identifier']	 	= '';

				$ipopt['auto_duration'] 	= '3';		
				$ipopt['add_home'] 			= true;
				$ipopt['add_single']		= true;
				$ipopt['add_archive'] 		= true;
				$ipopt['expected_loadtime']	= '6';
				$ipopt['fade_duration']		= '650';

				//VERSION 1.2
				$ipopt['captions'] = false;
				
				//VERSION 1.6
				$ipopt['gallery_identifier'] = '';

				//VERSION 1.8
				$ipopt['cutoff_image']	= true;
				$ipopt['show_ruler']	= false;
				$ipopt['ruler_color']	= 'rgb(0, 147, 173)';

				//VERSION 1.12
				$ipopt['showarrows']		= true;
				$ipopt['exclude_featured']	= true;
				
				//VERSION 2.0
				$ipopt['show_thumbstrip']	= true;
				
				//VERSION 2.3
				$ipopt['initviewstyle']		= 1;			
				$ipopt['exclude_images']	= '';		
				
				//VERSION 2.3
				$ipopt['overlays'] = '';
				
				update_option('image_projector_settings',$ipopt);
		

	}else { // new option setting found, make sure it contain the latest settings
			$do_update = false;
			//VERSION 1.12
			if(!isset( $ipopt['showarrows'])) {
					$ipopt['showarrows'] = true;
					$do_update = true;
				}
			if(!isset( $ipopt['exclude_featured'])) {
					$ipopt['exclude_featured'] = true;
					$do_update = true;
				}
			//VERSION 2.0
			if(!isset( $ipopt['show_thumbstrip'])) {
					$ipopt['show_thumbstrip'] = true;
					$do_update = true;
				}
			//VERSION 2.3
			if(!isset( $ipopt['initviewstyle'])) {
					$ipopt['initviewstyle'] = 1;
					$do_update = true;
				}
			if(!isset( $ipopt['exclude_images'])) {
					$ipopt['exclude_images'] = '';
					$do_update = true;
				}				
			//VERSION 2.3
			if(!isset( $ipopt['overlays'])) {
					$ipopt['overlays'] = '';
					$do_update = true;
				}
			
			if($do_update) {
				delete_option('image_projector_settings');
				update_option('image_projector_settings',$ipopt);
			}
				
	}
	return ($ipopt);
}

function wpiv_add_settings_link($links, $file) {
	static $this_plugin;
	if (!$this_plugin) $this_plugin = plugin_basename(__FILE__);
 
	if ($file == $this_plugin){
		$settings_link = '<a href="admin.php?page=wpiv-setting-admin">'.__("Settings", "image-projector").'</a>';
		array_unshift($links, $settings_link);
	}
	return $links;
 }
add_filter('plugin_action_links', 'wpiv_add_settings_link', 10, 2 );

function image_projector_load_plugin_textdomain() {
    load_plugin_textdomain( 'image-projector', FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );
}
add_action( 'plugins_loaded', 'image_projector_load_plugin_textdomain' );
		
function wpiv_set_dirty() {

	if(get_post_type() == 'post') {		
		$adminopt = get_option( 'image_projector_admin' );

		$adminopt['dirty'] = true;
		update_option('image_projector_admin',$adminopt);
	}

}

add_action ( 'post_updated', 'wpiv_set_dirty');
add_action ( 'deleted_post', 'wpiv_set_dirty');
add_action ( 'save_post', 'wpiv_set_dirty');
?>