<?php
/**
 * Belongs to WordPress plugin: Image Projector
 *
 */
if (!defined('ABSPATH')) {
	exit("'No direct access available'");
}

function wpiv_load_script()
{

	$options = wpiv_check_options();
	

	$ident				= $options['identifier'];
	$galleryident		= $options['gallery_identifier'];
	$excludeimages		= $options['exclude_images'];
	$overlays			= $options['overlays'];
	$menuh 				= 50;
	$menuovl			= true;
	$autoduration		= $options['auto_duration'];		
	$add_home			= $options['add_home'];
	$add_single			= $options['add_single'];
	$add_archive		= $options['add_archive'];	
	$expected			= $options['expected_loadtime'];
	$fadeduration		= $options['fade_duration'];
	$captions			= $options['captions'];
	$cutimage			= $options['cutoff_image'];	
	$showruler			= $options['show_ruler'];
	$rulercolor			= $options['ruler_color'];
	$showarrows			= $options['showarrows'];
	$exclude_featured 	= $options['exclude_featured'];	
	$show_thumbstrip 	= $options['show_thumbstrip'];
	$initviewstyle	 	= $options['initviewstyle'];
	
	$adminopt			= get_option('image_projector_admin');
	
	
	$systemWrappers		= '.ns_slides, .owl-stage, .gallery, .tiled-gallery, .envira-gallery-wrap, .ngg-galleryoverview, .galleria, .nextgen_pro_thumbnail_grid, .galleria-stage, .justified-image-grid, .sqs-gallery-container, .juice-box-container, .thumbs-item, .gallery-listviewer, .robo_gallery';
	
	$stamp 			= "";
	$isArchive 		= false;
	$loggedInUser 	= is_user_logged_in();
	$jArchiveImages = "";

	
	// for debugging purpose on the client side
	$phpver 		= phpversion();
	$phplog 		= "PHP ".$phpver." | ".WPIP_PLUGIN_DIR;
	
	if(class_exists('DOMDocument', false)) {
		$phplog = $phplog." | DOMDocument exist";
	}

	if($adminopt) {
		if(isset( $adminopt['stamp'] )) {
			$stamp = "_".$adminopt['stamp'];
		}
	}else {
		$adminopt['dirty'] = true;
		$adminopt['stamp'] = "";
		update_option('image_projector_admin',$adminopt);

	}

	if ((!is_admin() && ((is_single() && $add_single == true)
		|| (is_home() && $add_home == true) 
		|| (is_page() ) 
		|| (is_archive() && $add_archive == true))
		))
	{
		
		// create reference file if it does not exist. It's quick.
		$localfile 			= WPIP_REF_DIR."/wpiv-ref-".WPIP_VERSION.".js";
		$localfilecaption 	= WPIP_REF_DIR."/wpiv-ref-c-".WPIP_VERSION.".json";

		if($adminopt['dirty'] ||( !file_exists($localfile) || (!file_exists($localfilecaption) && $captions == true)))
		{ 
			wpiv_generate_postimage_reference_js($exclude_featured);
			$adminopt['dirty'] = false;
			$adminopt['stamp'] = filemtime($localfile);
			update_option('image_projector_admin',$adminopt);
			$phplog = $phplog." | Generated references";	
		} else {
			$phplog = $phplog." | Not dirty";
		}

	
		// need re-execute with no paging to get all posts in query as original query may be paged
		// this will ignore any pre_get_posts filters if set when is_main_query as this is not the main query
		if( (is_archive() && $add_archive == true))  {
			$phplog = $phplog." | An archive page";
			$isArchive = true;
			global $query_string;
			
			$temp_result = get_posts($query_string.'&posts_per_page=-1&order=ASC');
			$numArray = count($temp_result);
			$jArchiveImages = "";
			
			for($i=0;$i<$numArray;$i++){
				$jArchiveImages .=  $temp_result[$i]->ID;
				if($i < $numArray-1){ $jArchiveImages .= ',';}
			}
		} else{

			$jArchiveImages="";
		}

		$reloadstamp = time();
		// load google material design icon font
		wp_register_style( 'google_font_material', "https://fonts.googleapis.com/icon?family=Material+Icons");
		wp_enqueue_style( 'google_font_material');
		
		wp_register_style( 'wpiv_style', WPIP_PLUGIN_URL.'/public/css/ip-style.css',array(),$reloadstamp);
		wp_enqueue_style( 'wpiv_style');
	
		wp_register_script( 'wpiv_reference', WPIP_REF_URL.'/wpiv-ref-'.WPIP_VERSION.'.js',array(),WPIP_VERSION.$stamp,true);
		wp_enqueue_script( 'wpiv_reference');

		wp_register_script( 'wpiv_helpers', WPIP_PLUGIN_URL.'/public/js/image-projector-helpers.min.js',array('jquery'),$reloadstamp,true);	
		wp_enqueue_script( 'wpiv_helpers');

		if($showruler) {
			wp_register_script( 'wpiv_ruler', WPIP_PLUGIN_URL.'/public/js/ip-ruler.min.js',array('jquery'),WPIP_VERSION,true);	
			wp_enqueue_script( 'wpiv_ruler');
		}

		if($show_thumbstrip) {			
			wp_register_script( 'wpiv_thumbstrip', WPIP_PLUGIN_URL.'/public/js/ip-thumbstrip.min.js',array('jquery'),$reloadstamp,true);	
			wp_enqueue_script( 'wpiv_thumbstrip');
		}

		wp_register_script( 'wpiv_script', WPIP_PLUGIN_URL.'/public/js/image-projector.min.js',array('jquery'),$reloadstamp,true);
		wp_localize_script( 'wpiv_script', 'WPIVConfig', array(
			'cfg' => array (
				// user interface
				'bindto'			=> $ident,
				'captions'			=> $captions,
				'menuHeight'		=> intval($menuh),
				'menuOverlay'		=> $menuovl,			
				'autoDuration'		=> intval($autoduration),
				'expectedLoadtime'	=> intval($expected),
				'fadeDuration'		=> intval($fadeduration),
				'galleryWrappers'	=> $galleryident,
				'cutImage'			=> $cutimage,
				'showRuler'			=> $showruler,
				'rulerColor'		=> $rulercolor,
				'showArrows'		=> $showarrows,
				'showThumbStrip'	=> $show_thumbstrip,
				'initViewStyle'		=> $initviewstyle,
				'excludeImg'		=> $excludeimages,
				'overlays'			=> $overlays

				),
			'wpdata' => array (
				// system variables
				'wpPluginUrl'		=> WPIP_PLUGIN_URL,
				'wpUploadUrl'		=> WPIP_UPLOAD_URL,
				'version'			=> WPIP_VERSION,
				'postString'		=> $jArchiveImages,
				'isArchive'			=> $isArchive,
				'loggedInUser'		=> $loggedInUser,
				'phplog'			=> $phplog,
				'systemWrappers' 	=> $systemWrappers
				)

			)
		);
		wp_enqueue_script( 'wpiv_script');


		/**
		 * load 3rd party scripts
		*/		


		// remove old version of imageslaoded that came with WP
		wp_dequeue_script( 'imagesloaded');
		wp_deregister_script( 'imagesloaded');

		wp_register_script( 'imagesloaded', WPIP_PLUGIN_URL.'/public/js/vendor/imagesloaded.pkgd.min.js',array(),'4.1.1',true);
		wp_enqueue_script( 'imagesloaded');

		wp_register_script( 'hammer', WPIP_PLUGIN_URL.'/public/js/vendor/hammer.min.js',array(),null,true);
		wp_enqueue_script( 'hammer');	
		

	}
}
add_action('wp_enqueue_scripts', 'wpiv_load_script');

/**
 * Create a post reference file. 
*/
 
function wpiv_generate_postimage_reference_js($exclude_featured) {
	$doCaption	= true;
	$doThumb	= true;
	$doNotEdit	= '//do not edit this file'.PHP_EOL;
	$pinfo = array();
	$refDir = WPIP_PLUGIN_DIR."/admin/ref";

	if (!is_dir($refDir)) {
	 if(is_writable(WPIP_PLUGIN_DIR)){
			mkdir($refDir , 0755, true);
		}
		else return;
	}
	
	$jsFile = $refDir."/wpiv-ref-".WPIP_VERSION.".js";
	$handle = fopen($jsFile,"w");
	if($doThumb) {	
		$thumbFile = $refDir."/wpiv-ref-thumb-".WPIP_VERSION.".json";
		$thumbHandle = fopen($thumbFile,"w");	
	}
	// caption
	if($doCaption) {
		$jsonFile =  $refDir."/wpiv-ref-c-".WPIP_VERSION.".json";
		$jsonHandle = fopen($jsonFile ,"w");
	}
	// end caption
	global $post;
	global $wpdb;

	
	$querystr = "SELECT $wpdb->posts.* FROM $wpdb->posts WHERE $wpdb->posts.post_status = 'publish' AND ($wpdb->posts.post_type = 'post') ORDER BY $wpdb->posts.ID";
	$pageposts = $wpdb->get_results($querystr, OBJECT);

	
	$counts = 0 ;
	fwrite($handle, $doNotEdit);
	fwrite($handle, 'var wpiv_postarray = [];wpiv_postarray=[');

	if ($pageposts):

		// caption
		if($doCaption) {	
			fwrite($jsonHandle, '{');
			}
		// thumb
		if($doThumb) {		
			fwrite($thumbHandle, '{');
		}		
		
		foreach ($pageposts as $post):
			

			$foundimg = wpiv_get_all_post_images($post->ID, $exclude_featured);
			if(!empty($foundimg)) {
			
				foreach ($foundimg as $imageitem) {
					$counts++;
					
					// convert url to local file
					$localfile = str_replace(WPIP_UPLOAD_URL,"",$imageitem['name']);
					if((strpos($localfile,'http') === false) && ($imageitem['width'] == '' || $imageitem['height'] == '')) {
						// image w and h not defined, get it if it is a local file, otherwise - sorry
						// localfile is with preceeding slash so do not add between path and localfile
						$imgfname = WPIP_UPLOAD_DIR.$localfile;
						$imgsize  = getimagesize($imgfname);
						$imageitem['width'] 	= $imgsize[0];
						$imageitem['height'] 	= $imgsize[1];
					}
					if($counts > 1) fwrite($handle, ',');
					fwrite($handle, '['.$post->ID.','.$imageitem['width'].','.$imageitem['height'].',"'.$localfile.'"]');

					// caption
					if($doCaption) {
						$caption=json_encode(get_the_title($post->ID));
						if($counts > 1) fwrite($jsonHandle, ',');
						fwrite($jsonHandle,'"'.$post->ID.'":'.$caption);

					}
					// thumbs
					if($doThumb) {
						if( ! isset($imageitem['thumb'])) {
							// no thumb found, reuse the main image file and ratio for this purpose
							$thumbname = $localfile;
							$thumbratio = round($imageitem['width'] / $imageitem['height'], 3);
						} else {
							$thumbname = str_replace(WPIP_UPLOAD_URL,"",$imageitem['thumb']);
							
							if( ! file_exists(WPIP_UPLOAD_DIR.$thumbname)) {
								// the attached thubnail image has been removed for some reason
								// reuse the main image file and ratio for this purpose
								$thumbname = $localfile;
								$thumbratio = round($imageitem['width'] / $imageitem['height'], 3);
								
							} else {
								// thumb is OK, use the ratio from thumb, it may be different from main image
								$thumbratio = $imageitem['thumbratio'];
							}
						}
						if($counts > 1) fwrite($thumbHandle, ',');
						fwrite($thumbHandle,'"'.$post->ID.'":{"name":"'.$thumbname.'","ratio":"'.$thumbratio.'"}');
	

					}					
				}
 
			}
		endforeach;
		// caption
		if($doCaption) {
			fwrite($jsonHandle, '}');
		}
		// thumbs
		if($doThumb) {
			fwrite($thumbHandle, '}');
		}		


	endif;
	fwrite($handle, '];');
	fclose($handle);
	
	if($doThumb) {	
		fclose($thumbHandle);
	}
	
	if($doCaption) {
		fclose($jsonHandle);
	}		

}  




/**
 * For increased performance (but not necessary) when loading first image, a data-attribute -postid- containing the post ID can be added to img element.
*/
function wpiv_img_add_postid($content) {
	global $post;
	
	$replaceto = "img data-ippostid='$post->ID' ";
	$retval = str_replace ("img ",$replaceto,$content);

	return $retval;
}
add_filter('the_content', 'wpiv_img_add_postid');

function wpiv_get_all_post_images($postid, $exclude_featured) {
	global $wpdb;

	$thispost = get_post($postid);	
	$content = $thispost->post_content	;
	$foundimg = array();
	
	$inum 	= 0;
	$img_ext = "";
	$supported_ext = array(
    "jpg",
    "jpeg",
    "gif",
    "png"
    );
	if (class_exists('DOMDocument')) {
		$doc = new DOMDocument();
		libxml_use_internal_errors(true); // 2.6, DOMDocument not able to parse HTML5, silent error handling
		$doc->loadHTML('<?xml encoding="UTF-8">' . $content);
		libxml_clear_errors(); // 2.6
		
		foreach ($doc->getElementsByTagName('img') as $img)
		{	$src = "";
			$href = "";
			// if img is surrounded by an anchor tag, get the href value
			$href = $img->parentNode->getAttribute('href');
			
			if ($href != "") { 
				// yes, surrounded by anchor tag, but is it an image link?
				$img_ext = pathinfo($href, PATHINFO_EXTENSION);
				
				// yes, it was an anchor with a link to an image
				if (in_array(strtolower($img_ext), $supported_ext) == true) {
					$src = $href;
				} else {
					// but no the proper image file
					$src = "";
				}
			}

			if($src == "") {
				// if not set above, take the src attribute on the image element
				$src = $img->getAttribute('src');
			}

			$alt = $img->getAttribute('alt');
			if($alt == "") {
				$alt="Untitled";
			}

			$foundimg[$inum]['alt'] 	= $alt;
			$foundimg[$inum]['name'] 	= $src;
			$foundimg[$inum]['width'] 	= 0; // will get the size later
			$foundimg[$inum]['height'] 	= 0; // will get the size later

			// try to get assigned thumbnail
			// get attachment id of the main image
			$attachid = attachment_url_to_postid($src );
			
			// generate the name of the thumbnail file
			$thumbatt = wp_get_attachment_image_src( $attachid,'thumbnail' );		

			// if found
			if($thumbatt) 
			{
				// checking if the file actually exists will be done later
				$foundimg[$inum]['thumb']	= $thumbatt[0];
				$foundimg[$inum]['thumbratio'] =  round($thumbatt[1] / $thumbatt[2], 3);
			}
			// if not found, we cheat a bit during writing - see above
			
			
			$inum++;  
		}
	}
	if($inum == 0 || ($inum > 0 && ! $exclude_featured)) {
		if ( has_post_thumbnail($postid) ) {

			$featured = wp_get_attachment_image_src( get_post_thumbnail_id( $postid), 'single-post-thumbnail' );
			
			$foundimg[$inum]['name'] 	=  $featured[0];
			$foundimg[$inum]['width']	=  $featured[1];
			$foundimg[$inum]['height']	=  $featured[2];
			$inum++;	
		}
	}
	
	return $foundimg;
} 


?>