<?php
/**
 * Belongs to WordPress plugin: Image Projector
 *
 */
if (!defined('ABSPATH')) {
	exit("'No direct access available'");
}

/**
 * The plugin admin page
*/
class WPIVSettingsPage
{
    private $options;


	private function openSection($title) {
		printf('<div class="meta-box-sortables"><div class="postbox"><h3 class="hndle"><span>'.$title.'</span></h3>');
		printf('<div class="inside">');

	}

	private function closeSection() {
			
		printf('</div></div></div>'); //closing inside, postbox, meta-box-sortables	
		
	}

	private function getTooltip() {
		$tooltip = __("Use dot before a class name and # before an ID, like .classname, #thisID.\nMultiple elements shall be separated by comma.","image-projector");
		return($tooltip);
	}
	
    public function __construct()
    {
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );


        add_action( 'admin_init', array( $this, 'page_init' ) );
    }

 
    public function add_plugin_page()
    {
        add_options_page('Settings Admin', 'Image Projector',   'manage_options', 'wpiv-setting-admin', array( $this, 'create_admin_page' )
        );
		
	
    }

    public function create_admin_page()
    {   

		wpiv_check_options();
		$this->options = get_option( 'image_projector_settings' );

        ?>
        <div class="wrap">
            <h2>Image Projector <?php echo WPIP_VERSION?></h2>           
            <form method="post" action="options.php">
            <?php
				settings_fields( 'wpiv_option_group' );
				do_settings_sections( 'wpiv-setting-admin' );
				$this->closeSection();				
				submit_button();  
			?>
	        </form>
        </div>
        <?php
    }

    public function page_init()
    {   
        register_setting(
            'wpiv_option_group', 'image_projector_settings', array( $this, 'sanitize' )
        );
		// setting section 'Activate' 
        add_settings_section(
            'wpiv_settings_main', '', array( $this, 'print_main_section_info' ), 
            'wpiv-setting-admin'
        );  

		
		add_settings_field(
            'add_home', __('Use on home page','image-projector'), array( $this, 'add_home_callback' ), 
            'wpiv-setting-admin', 'wpiv_settings_main'
        );
		add_settings_field(
            'add_archive', __('Use on archive pages','image-projector'), array( $this, 'add_archive_callback' ), 
            'wpiv-setting-admin', 'wpiv_settings_main'
        );	
		add_settings_field(
            'add_single', __('Use on single post pages','image-projector'), array( $this, 'add_single_callback' ), 
            'wpiv-setting-admin', 'wpiv_settings_main'
        );
		add_settings_field(
            'expected_loadtime', __('Max expected image load time','image-projector'), array( $this, 'expected_loadtime_callback' ), 
            'wpiv-setting-admin', 'wpiv_settings_main'
        );

		add_settings_field(
            'identifier', __('Include only these images','image-projector'), array( $this, 'identifier_callback' ), 
            'wpiv-setting-admin', 'wpiv_settings_main'
        );
		add_settings_field(
            'exclude_images', __('Exclude these images','image-projector'), array( $this, 'exclude_images_callback' ), 
            'wpiv-setting-admin', 'wpiv_settings_main'
        );	 	
		add_settings_field(
            'overlays', __('Image overlays','image-projector'), array( $this, 'overlays_callback' ), 
            'wpiv-setting-admin', 'wpiv_settings_main'
        );	
		add_settings_field(
            'gallery_identifier', __('Gallery wrappers','image-projector'), array( $this, 'gallery_identifier_callback' ), 
            'wpiv-setting-admin', 'wpiv_settings_main'
        );
		add_settings_field(
            'exclude_featured', __('Exclude featured image','image-projector'), array( $this, 'exclude_featured_callback' ), 
            'wpiv-setting-admin', 'wpiv_settings_main'
        );
		
		// setting section 'User interface' 
		add_settings_section(
            'wpiv_settings_layout','', array( $this, 'print_layout_section_info' ), 
            'wpiv-setting-admin' 
        );

        add_settings_field('initviewstyle', __('Initial view style','image-projector'), array( $this, 'initviewstyle_callback' ), 
            'wpiv-setting-admin', 'wpiv_settings_layout'
        );
		add_settings_field(
			'cutoff_image',  __('Cut off image','image-projector'), array( $this, 'cutoff_image_callback' ), 
			'wpiv-setting-admin', 'wpiv_settings_layout'
		);
		add_settings_field(
            'auto_duration', __('Time to next slide (auto)','image-projector'), array( $this, 'auto_duration_callback' ), 
            'wpiv-setting-admin', 'wpiv_settings_layout'
        );		
		add_settings_field(
			'fade_duration', __('Crossfade duration','image-projector'), array( $this, 'fade_duration_callback' ), 
			'wpiv-setting-admin', 'wpiv_settings_layout'
		);
        add_settings_field('showarrows', __('Show arrows','image-projector'), array( $this, 'showarrows_callback' ), 
            'wpiv-setting-admin', 'wpiv_settings_layout'
        );
		
        add_settings_field('captions', __('Support captions','image-projector'), array( $this, 'captions_callback' ), 
            'wpiv-setting-admin', 'wpiv_settings_layout'
        );			
		add_settings_field(
			'show_thumbstrip', __('Show thumbstrip','image-projector'), array( $this, 'show_thumbstrip_callback' ), 
			'wpiv-setting-admin', 'wpiv_settings_layout'
		);


		add_settings_field(
			'show_ruler', __('Show ruler on desktops','image-projector'), array( $this, 'show_ruler_callback' ), 
			'wpiv-setting-admin', 'wpiv_settings_layout'
		);

	


    }

    public function print_main_section_info()
    {

		//open the section
		$this->openSection(__('Activation','image-projector'));
		
		 
    }
	
    public function print_layout_section_info()
    {
		$this->closeSection();
		submit_button();
		$this->openSection(__('User interface','image-projector'));


    }	
	public function identifier_callback() {
		$msg = __('You may limit the images by specifying IDs and classes, otherwise all images will open in this plugin.','image-projector');
		
		printf(
            '<input type="text" id="identifier" name="image_projector_settings[identifier]" value="%s" title="'.$this->getTooltip().'"></input>',
            isset( $this->options['identifier'] ) ? esc_attr( $this->options['identifier']) : ''
        );
		printf('<tr><th class="small"></th><td class="small">'.$msg.'</td></tr>');	
	
	}
	public function exclude_images_callback() {
		$msg = __('You may exclude images having the specified IDs or classes.','image-projector');
		
		printf(
            '<input type="text" id="exclude_images" name="image_projector_settings[exclude_images]" value="%s" title="'.$this->getTooltip().'"></input>',
            isset( $this->options['exclude_images'] ) ? esc_attr( $this->options['exclude_images']) : ''
        );
		printf('<tr><th class="small"></th><td class="small">'.$msg.'</td></tr>');	
	
	}
	public function overlays_callback() {
		$msg = __('Specify classes or IDs of any div elements overlying images.','image-projector');
		
		printf(
            '<div id="ip-overlays"><input type="text" id="overlays" name="image_projector_settings[overlays]" value="%s" title="'.$this->getTooltip().'"></input></div>',
            isset( $this->options['overlays'] ) ? esc_attr( $this->options['overlays']) : ''
        );
		printf('<tr><th class="small"></th><td class="small">'.$msg.'</td></tr>');	
	
	}	
	
	public function gallery_identifier_callback() {
		$msg = __('Normally, galleries and other group of images are detected automatically. If you are not able to navigate through all images in a group, specify the class or ID for the group, like .my-gallery-wrapper.','image-projector');
		
		printf('
            <input type="text" id="gallery-identifier" name="image_projector_settings[gallery_identifier]" value="%s" title="'.$this->getTooltip().'"></input>',
            isset( $this->options['gallery_identifier'] ) ? esc_attr( $this->options['gallery_identifier']) : ''
        );
		printf('<tr><th class="small"></th><td class="small">'.$msg.'</td></tr>');	
	
	}	
    public function add_home_callback()
    {

        printf(
		'<input type="hidden" name="image_projector_settings[add_home]" value="0" />'.
            '<input type="checkbox" id="add_home" value="1" name="image_projector_settings[add_home]"' . ($this->options['add_home'] == 1?'checked=\"checked\"':'') . '/>'

        );
    }
	public function add_archive_callback()
    {

        printf(
		'<input type="hidden" name="image_projector_settings[add_archive]" value="0" />'.		
            '<input type="checkbox" id="add_archive" value="1" name="image_projector_settings[add_archive]"' . ($this->options['add_archive'] == true?'checked=\"checked\"':'') . '/>'

        );
    }	
	public function add_single_callback()
    {

        printf(
				'<input type="hidden" name="image_projector_settings[add_single]" value="0" />'.		
            '<input type="checkbox" id="add_single" value="1" name="image_projector_settings[add_single]" ' . ($this->options['add_single'] == true?'checked=\"checked\"':'') .  '/>'
		
        );
		
    }
	public function exclude_featured_callback()
    {
		$msg = __('Excludes featured image if there are images attached to the post. Used when generating references for images in posts and prevents possibility for duplicate images.','image-projector');
        printf(
				'<input type="hidden" name="image_projector_settings[exclude_featured]" value="0" />'.		
            '<input type="checkbox" id="exclude_featured" value="1" name="image_projector_settings[exclude_featured]" ' . ($this->options['exclude_featured'] == true?'checked=\"checked\"':'') .  '/>'
		
        );
		printf('<tr><th class="small"></th><td class="small">'.$msg.'</td></tr>');
		
    }	
	public function expected_loadtime_callback()
    {

		$msg = __('Waiting time before \'slow connection\' message appears.','image-projector');
		
        printf(
            '<input type="text" style="width:40px" id="expected_loadtime" name="image_projector_settings[expected_loadtime]" value="%s" /><span class="ip-label">[seconds]</span>',
            isset( $this->options['expected_loadtime'] ) ? esc_attr( $this->options['expected_loadtime']) : '6'
        );
		printf('<tr><th class="small"></th><td class="small">'.$msg.'</td></tr>');		
    }	

	
	
	
	
	public function captions_callback()
    {

        printf('<input type="hidden" name="image_projector_settings[captions]" value="0" />'.		
            '<input type="checkbox" id="captions" value="1" name="image_projector_settings[captions]" ' . ($this->options['captions'] == true?'checked=\"checked\"':'') .  '/>'
        );
    }

	public function initviewstyle_callback()
    {

   ?>
        <label class="ip-radiolabel"><input type="radio" id="style1" name="image_projector_settings[initviewstyle]" value="1" <?php checked(1, $this->options['initviewstyle'], true); ?>/>&nbsp;<?php _e('Inside square','image-projector')?></label>
        <label class="ip-radiolabel"><input type="radio" id="style2" name="image_projector_settings[initviewstyle]" value="2" <?php checked(2, $this->options['initviewstyle'], true); ?>/>&nbsp;<?php _e('With frame','image-projector')?></label>
        <label class="ip-radiolabel"><input type="radio" id="style3" name="image_projector_settings[initviewstyle]" value="3" <?php checked(3, $this->options['initviewstyle'], true); ?>/>&nbsp;<?php _e('As big as possible','image-projector')?></label>		
   <?php
		printf('<tr><th class="small"></th><td><div class="viewstyle-image-wrapper"><img class="viewstyle-image" src="'.plugin_dir_url( __FILE__ ) . '../admin/img/viewStyle'.$this->options['initviewstyle'].'.jpg" data-path="'.plugin_dir_url( __FILE__ ).'"></div></td></tr>');
    }
	
	public function showarrows_callback()
    {
		
        printf('<input type="hidden" id="ip-showarrows" name="image_projector_settings[showarrows]" value="0" />'.		
            '<input type="checkbox" id="showarrows" value="1" name="image_projector_settings[showarrows]" ' . ($this->options['showarrows'] == true?'checked=\"checked\"':'') .  '></input>'
        );

		printf('<tr><th class="small"></th><td class="small">'.__("You may in any case navigate with arrow keys or mouse.","image-projector").'</td></tr>');

    }
	public function auto_duration_callback()
    {
		$seconds = __("seconds","image-projector");

        printf(
            '<input type="text" style="width:40px" id="auto_duration" name="image_projector_settings[auto_duration]" value="%s" ><span class="ip-label">['.$seconds.'] >= 3</span></input>',
            isset( $this->options['auto_duration'] ) ? esc_attr( $this->options['auto_duration']) : '3'
        );
    }	
	public function fade_duration_callback()
    {
		$milliseconds = __("milliseconds","image-projector");
		
        printf(
            '<input type="text" style="width:40px" id="fade_duration" name="image_projector_settings[fade_duration]" value="%s" ><span class="ip-label">['.$milliseconds.'] 1 - 2000</span></input>',
            isset( $this->options['fade_duration'] ) ? esc_attr( $this->options['fade_duration']) : '650'
        );

    }
	public function cutoff_image_callback()
    {

		$msg = __('Cut-off applies to full view. When gutter widths are less than 4 percent of window width or height, silently overflow image for a gapless fit without changing aspect ratio of image.','image-projector');
		
        printf('<input type="hidden" id="ip-cutoff" name="image_projector_settings[cutoff_image]" value="0" />'.
            '<input type="checkbox" id="cutoff_image" value="1" name="image_projector_settings[cutoff_image]" ' . ($this->options['cutoff_image'] == true?'checked=\"checked\"':'') . '></input>'
        );

		printf('<tr><th class="small"></th><td class="small">'.$msg);
		 
		printf('<div class="cutoff-image-wrapper"><img title="Turned OFF" class="cutoff-image" src="'.plugin_dir_url( __FILE__ ) . '../admin/img/cutoff_OFF.jpg"'.'>');
		printf('<img title="Turned ON" class="cutoff-image" src="'.plugin_dir_url( __FILE__ ) . '../admin/img/cutoff_ON.jpg"'.'></div></td></tr>'); 
    }	
	public function show_ruler_callback()
    {
 
        printf(
            '<div class="color-picker" ><input type="hidden" name="image_projector_settings[show_ruler]" value="0" /><input type="checkbox" id="show_ruler" value="1" name="image_projector_settings[show_ruler]" '  . ($this->options['show_ruler'] == true?'checked=\"checked\"':'') . '/>'.'<input type="text" id="ruler_color" value="%s" name="image_projector_settings[ruler_color]" class="ruler-color" />',

			isset( $this->options['ruler_color'] ) ? esc_attr( $this->options['ruler_color']) : ''
	
        );

    }
	public function show_thumbstrip_callback()
    {
        printf(
				'<input type="hidden" name="image_projector_settings[show_thumbstrip]" value="0" />'.		
            '<input type="checkbox" id="show_thumbstrip" value="1" name="image_projector_settings[show_thumbstrip]" ' . ($this->options['show_thumbstrip'] == true?'checked=\"checked\"':'') . '></input>'
				
        );

		
    }
	
	// sanitizers
    public function sanitize( $input )
    {
        $new_input = array();

       if( isset( $input['identifier'] ) )
           $new_input['identifier'] = sanitize_text_field( $input['identifier'] );
	   
       if( isset( $input['exclude_images'] ) )
           $new_input['exclude_images'] = sanitize_text_field( $input['exclude_images'] );

       if( isset( $input['overlays'] ) )
           $new_input['overlays'] = sanitize_text_field( $input['overlays'] );
	   
	   
        if( isset( $input['gallery_identifier'] ) )
            $new_input['gallery_identifier'] = sanitize_text_field( $input['gallery_identifier'] );

		if($input['add_home'] == true) {$new_input['add_home'] = true;}
		 else {$new_input['add_home'] = false; }

		if($input['add_archive'] == true) {$new_input['add_archive'] = true;}
		 else {$new_input['add_archive'] = false; }		

		if($input['add_single'] == true) {$new_input['add_single'] = true;}
		 else {$new_input['add_single'] = false; }



		if( isset( $input['expected_loadtime'] ) ){
		$new_input['expected_loadtime'] = sanitize_text_field( $input['expected_loadtime'] );
		 if((int)$new_input['expected_loadtime'] < 1) {
			 $new_input['expected_loadtime']="1";
			 }
		 }
		 
		if($input['exclude_featured'] == true) {$new_input['exclude_featured'] = true;}
		 else {$new_input['exclude_featured'] = false; }
		 
		if($input['captions'] == true) {$new_input['captions'] = true;}
		 else {$new_input['captions'] = false; }
		
		//
		
		if($input['initviewstyle'] == true) {$new_input['initviewstyle'] = true;}
		 else {$new_input['initviewstyle'] = false; }	
		if( isset( $input['initviewstyle'] ) ){
			$new_input['initviewstyle'] = sanitize_text_field( $input['initviewstyle'] );
			 if((int)$new_input['initviewstyle'] < 1 || (int)$new_input['initviewstyle'] > 3) {
				 $new_input['initviewstyle']='1';
				 }
			 }
		 //
		if($input['showarrows'] == true) {$new_input['showarrows'] = true;}
		 else {$new_input['showarrows'] = false; }		 
	
		if( isset( $input['auto_duration'] ) ){
			$new_input['auto_duration'] = sanitize_text_field( $input['auto_duration'] );
			 if((int)$new_input['auto_duration'] < 3) {
				 $new_input['auto_duration']="3";
				 }
			 }
		if( isset( $input['fade_duration'] ) ){
		$new_input['fade_duration'] = sanitize_text_field( $input['fade_duration'] );
		 if((int)$new_input['fade_duration'] < 1 || (int)$new_input['fade_duration'] > 2000) {
			 $new_input['fade_duration']='650';
			 }
		 }		 

		 
		if($input['cutoff_image'] == true) {$new_input['cutoff_image'] = true;}
		 else {$new_input['cutoff_image'] = false; }

		 		 
		if($input['show_ruler'] == true) {$new_input['show_ruler'] = true;}
		 else {$new_input['show_ruler'] = false; }

		$new_input['ruler_color'] = $input['ruler_color'];
		if( !isset( $input['ruler_color'] ) ) $new_input['ruler_color'] = 'rgb(0, 147, 173)';

		
		if($input['show_thumbstrip'] == true) {$new_input['show_thumbstrip'] = true;}
		 else {$new_input['show_thumbstrip'] = false; }
		
		
        return $new_input;
    }	

}

if( is_admin() ) {
	$wpiv_settings_page = new WPIVSettingsPage();
}

function wpiv_admin_register_head() {

	$url =  WPIP_PLUGIN_URL . '/admin/css/plugin.css';
    echo "<link rel='stylesheet' type='text/css' href='$url?v=".WPIP_VERSION."' />\n";
}

add_action('admin_head', 'wpiv_admin_register_head');

function wpiv_enqueue_color(){
    wp_enqueue_style( 'wp-color-picker' );
    wp_enqueue_script( 
        'colorpick', 
        WPIP_PLUGIN_URL . '/admin/js/settings.js', 
        array( 'wp-color-picker'),
        false,
        true );
}
add_action('admin_enqueue_scripts', 'wpiv_enqueue_color');

?>