/**
 * Belongs to WordPress plugin: Image Projector
 *
 */
 
// In case not supported in browser
// Production steps of ECMA-262, Edition 5, 15.4.4.14
// Reference: http://es5.github.io/#x15.4.4.14
if (!Array.prototype.indexOf) {
  Array.prototype.indexOf = function(searchElement, fromIndex) {

    var k;

    if (this == null) {
      throw new TypeError('"this" is null or not defined');
    }

    var O = Object(this);

    var len = O.length >>> 0;

    if (len === 0) {
      return -1;
    }

    var n = +fromIndex || 0;

    if (Math.abs(n) === Infinity) {
      n = 0;
    }

    if (n >= len) {
      return -1;
    }

    k = Math.max(n >= 0 ? n : len - Math.abs(n), 0);

    while (k < len) {
      if (k in O && O[k] === searchElement) {
        return k;
      }
      k++;
    }
    return -1;
  };
}

	
function ipCheckTouch() {
	var msTouchEnabled; 
	var el = document.createElement('div');
	var eventName = 'ontouchstart';
	var isSupported = (eventName in el);

	msTouchEnabled = ((window.navigator.maxTouchPoints > 0)
		|| (window.navigator.msMaxTouchPoints > 0));	
	
	if(msTouchEnabled) { isSupported = true;}
	if (!isSupported) {
		el.setAttribute(eventName, 'return;');
		isSupported = typeof el[eventName] === 'function';
	}
	el = null;

	return isSupported;

}

function ipHasTranslate3d() {
	// https://gist.github.com/lorenzopolidori/3794226
	
	if (!window.getComputedStyle) {
		return false;
	}

	var el = document.createElement('p'), 
		has3d,
		transforms = {
			'webkitTransform':'-webkit-transform',
			'OTransform':'-o-transform',
			'msTransform':'-ms-transform',
			'MozTransform':'-moz-transform',
			'transform':'transform'
		};

	document.body.insertBefore(el, null);

	for (var t in transforms) {
		if (el.style[t] !== undefined) {
			el.style[t] = "translate3d(1px,1px,1px)";
			has3d = window.getComputedStyle(el).getPropertyValue(transforms[t]);
		}
	}

	document.body.removeChild(el);

	return (has3d !== undefined && has3d.length > 0 && has3d !== "none");
}

function ipWhichTransitionEnd ()  {
	// https://github.com/EvandroLG/transitionEnd
	
	var el = document.createElement('p');
	var	ret = '';
	var transitions = {
		'WebkitTransition' : 'webkitTransitionEnd',
		'MozTransition'    : 'transitionend',
		'MSTransition'     : 'msTransitionEnd',				
		'OTransition'      : 'oTransitionEnd otransitionend',
		'transition'       : 'transitionend'
	};
	
	document.body.insertBefore(el, null);
	
	for(var t in transitions){
		if(el.style[t] !== undefined){
			ret = transitions[t];
		}
	}
	document.body.removeChild(el);
	return (ret);
}

function ipStripTrailingSlash(rawurl) {

    if (rawurl.endsWith('/')) {
        return rawurl.slice(0, -1);
    }
    return rawurl;

}
function ipIsImageFile(fname) {
	var ext = "";
	ext = fname.slice((fname.lastIndexOf(".") - 1 >>> 0) + 2);
	ext = ext.toLowerCase();
	
	return (ext === 'jpg' || ext === 'gif' || ext === 'png' || ext === 'jpeg');

	
}

function ipGetImageSrc(img) {
	
	if(img.parent().is("a")) {
		var href = img.parent().attr("href");
		if(ipIsImageFile(href)) {
			src = href;
		} else {
			src = img.attr("src");
		}
	} else {
		src = img.attr("src");
	}
	
	return(src);

}

function ipCleanURL (rawurl) {
	var src, strindex;

	// clear url for any parameters
	strindex = rawurl.indexOf("?");
	
	if(strindex > -1) {
		src = rawurl.substr(0, strindex);
	}else {
		src = rawurl;
	}	
	return(src);
}
/*
 * debouncedresize: special jQuery event that happens once after a window resize
 *
 * latest version and complete README available on Github:
 * https://github.com/louisremi/jquery-smartresize
 *
 * Copyright 2012 @louis_remi
 * Licensed under the MIT license.
 *
 * This saved you an hour of work? 
 * Send me music http://www.amazon.co.uk/wishlist/HNTU0468LQON
 */
(function($) {

var $event = $.event,
	$special,
	resizeTimeout;

	$special = $event.special.debouncedresize = {
		setup: function() {
			$( this ).on( "resize", $special.handler );
		},
		teardown: function() {
			$( this ).off( "resize", $special.handler );

		},
		handler: function( event, execAsap ) {
			// Save the context

			var context = this,
				args = arguments,
				dispatch = function() {
					// set correct event type
					event.type = "debouncedresize";
					$event.dispatch.apply( context, args );
				};

			if ( resizeTimeout ) {
					
				clearTimeout( resizeTimeout );
			}

			execAsap ?
				dispatch() :
				resizeTimeout = setTimeout( dispatch, $special.threshold );
		},
		threshold: 150
};



})(jQuery);