/**
 * Belongs to WordPress plugin: Image Projector
 *
 */
"use strict"; 
;(function ( $ ) {

    var pluginName = "ipruler",
        defaults = {
			color : 'rgba(0, 147, 173, .6)'
        };


    function Plugin( element, options ) {
		this.wrapper 	= element;
		this.options 	= $.extend( {}, defaults, options) ;

        this.defaults	= defaults;
        this.name 		= pluginName;

		
		// global variables
		this._count		= 1;
		this._current	= 0;
		this._visible	= false;
		this._el		= Array();
		this._temphide	= false;
        this._init();
	
		return this;
    }

    Plugin.prototype = {

		_init: function() {
			this._appendMarkup();
			this._handleEvents();


		},
		_setCount: function(count) {
			
			this._count = count;
			
		},	
		_appendMarkup: function() {
			var self 		= this;
			var html 		= '';
			var colr 		= self.options.color;
			var el			= self._el;

			
			html ='<div id="ip-ruler-underlay">';
			html+='<div id="ip-ruler-container" class="ip-ruler" style="background:'+colr+'"></div>';
			html+='<div id="ip-ruler-progress" class="ip-ruler" style="background:'+colr+'"></div>';
			html+='<div id="ip-ruler-current" class="ip-ruler" style="background:'+colr+'"></div>';
			html+='</div>';

			// append to wrapper
			$(self.wrapper).append(html);
			
			el.rulerunderlay		= $(self.wrapper).find('#ip-ruler-underlay');
			el.rulercontainer		= $(el.rulerunderlay).find('#ip-ruler-container');
			el.ruler				= $(el.rulerunderlay).find('#ip-ruler-progress');
			el.rulercurrent			= $(el.rulerunderlay).find('#ip-ruler-current');				

		},
		_handleEvents: function(e) {
			var self = this;

			$(document).on('currentchange.ip', function(e, current) {

				self._updateRuler(current);
			});
			
			$(document).on('countChange.ip', function(e, count) {

				self._setCount(count);

			});
			
			self._el.rulerunderlay.on('click', function(e) {
				
				e.stopPropagation();
				self._setCurrentByClick(e.pageX);
				
			});
	 
			$( window ).on('debouncedresize', (function(e) {
				self._updateRuler();
			}));				
		},
		_getStep : function() {
			var self = this;
			
			return(self._el.rulercontainer.innerWidth() / self._count);
		},
		
		_setCurrentByClick : function(posX) {
			var self		= this;
			var newcurrent 	= Math.ceil(posX / this._getStep()) - 1;

			if(newcurrent != self._current) {
				self._current = newcurrent;

				
				$(document).trigger('navigateto.ip',[self._current]);
			}	
		},
		
		_updateRuler : function(newcurrent) {
	
			var self	= this;
			var step 	= self._getStep();

			
			if(typeof newcurrent !== 'undefined') {
				self._current = newcurrent;
			}
			
			var  title = "Showing slide " + (self._current + 1) + " of " + self._count;
			
			self._el.ruler.css({'left':0 + 'px','width':Math.ceil(self._current * step) + 'px'})
				.attr({"title": title});
				
			self._el.rulercurrent.css({
				'left':Math.max(0, self._current) * step + 'px','width':Math.ceil(step) + 'px'})
				.attr({"title": title});
		},

	
		show: function(showit) {
			var self = this;
			
			self._visible = (showit === undefined) ? ! self._visible : showit;
			
			if(self._visible){
				self._el.rulerunderlay.show();
				self._updateRuler();
			}else{
				self._el.rulerunderlay.hide();
			}

		},
		hide: function() {
			var self = this;

			if( ! self._visible) {return;}

			self._temphide = true;
			self._el.rulerunderlay.hide();
		},
		unhide: function() {
			var self = this;

			if( ! self._temphide) {return;}

			self._temphide = false;
			self._el.rulerunderlay.show();
			self._updateRuler();			
		}

	};

    $.fn[pluginName] = function ( options ) {
		return (new Plugin( this, options ));

    };
})( jQuery);
