/**
 * Belongs to WordPress plugin: Image Projector
 *
 */

"use strict"; 
;(function ( $ ) {

    var pluginName = "ipthumbstrip",
        defaults = {
			stripheight: 82,
			uploadurl : ''
        };


    function Plugin( element, options ) {
		this.wrapper 	= element;
		this.options 	= $.extend( {}, defaults, options) ;

        this.defaults	= defaults;
        this.name 		= pluginName;

		
		// plugin globals

		this._el			= Array();
		this._thumblist 	= Array();
		this._minx 			= 0;
		this._stripwidth	= 0;
		this._transitionEnd = "";
		this._currentthumb 	= 0;
		this._currentx		= 0;
		this._thumbmargin	= 1;
		this._temphide		= false;
        this._init();	
		return this;
    }

    Plugin.prototype = {

		_init: function() {

			this._transitionEnd = ipWhichTransitionEnd();
		},

		buildstrip : function(arr, num, initvisible) {
			var self	= this;
			var alen	= arr.length;

			var html = "";
			var currentclass;
			var newleft = 0;
			self._visible		= initvisible;
			self._thumbwidth	= self.options.stripheight;
			self._thumbheight	= self.options.stripheight;	
			self._stripwidth	= 0;
			self._hammer 		= null;
			self._el.container	= null;
			self._el.innerwrap	= null;
			self._el.toggler 	= null;
			self._currentthumb 	= num;

			html += '<div id="ip-thumbstrip-container" class="cursor-idle" style="height:'+(self._thumbheight+2*self._thumbmargin)+'px">';

			html += '<div id="ip-thumbstrip-outerwrapper">';
			html += '<div id="ip-thumbstrip-innerwrapper">';

			for (var i = 0; i < alen; i++) {

				var src = arr[i].name;
				var ratio = arr[i].ratio;
				
				currentclass = (i === num ? " ip-thumb-current":"");

				newleft = i * ((self._thumbmargin * 2) + self._thumbwidth);

				// the thumb
				html += '<div class="ip-thumbwrapper'+currentclass+'" data-seqno="'+i+'" id="thumbwrapper-'+i+'" style="left:'+newleft+'px;margin:'+self._thumbmargin+'px;height:'+self._thumbheight+'px;width:'+self._thumbwidth+'px';

				html += '; background-image: url('+src+');background-size:contain">';	

				self._stripwidth = self._stripwidth + self._thumbheight + 2 * self._thumbmargin;
				
				html += '</div>';
				// end of the thumb
			}


			html += '</div></div>';

			html += '</div>'; // closing container
			

			$(self.wrapper).append(html);
			
			
			html = '<div id="ip-thumbstrip-toggle" title="Toggle thumbstrip" class="ip-thumbstrip-toggle  ip-floating-button material-icons md-sz-floating mi-align ip-button-color '+(initvisible?'ip-thumbstrip-visible':'ip-thumbstrip-hidden')+'">'+'&#xE8D5' + ';</div>';
			$('#ip-floating-buttons').append(html);
			
			self._el.container	= $(self.wrapper).find('#ip-thumbstrip-container');
			self._el.innerwrap	= $(self._el.container).find('#ip-thumbstrip-innerwrapper');
			self._el.toggler 	= $(self.wrapper).find('#ip-thumbstrip-toggle');
			self._minx = self._getminx();
			self._moveintoview(num, true);
			
			self._el.innerwrap.imagesLoaded( function() {
				// thumbs have loaded
				self._handleEvents();
			});	

			return (self._el.toggler);


		},
		_getminx : function () {
			var self = this;

			return(self.wrapper.width() - self._stripwidth);
		},
		isvisible: function() {
			var self = this;
			return(self._visible);
		},
		gettoggler : function() {
			var self = this;
			
			return(self._el.toggler);
		},
		reset : function () {
			var self = this;
			if(self._hammer) {
				self._hammer.destroy();
				delete self._hammer;
	
			}
			self.off();
			if(self._el.container) {
				
				$(".ip-thumbwrapper").off('mousedown');

				$("#ip-thumbstrip-toggle").off('click.ip');				
				self._el.container.remove();
				self._el.toggler.remove();
			}
		},
		
		_handleEvents: function() {
			var self 			= this;
			var busy 			= false;
			var panstarted 		= false;
			var slider 			= self._el.innerwrap;
			self._currentx 		= 0;
			
			self._hammer = new Hammer.Manager(document.getElementById("ip-thumbstrip-innerwrapper"), {
				recognizers: [
					[Hammer.Pan, {direction: Hammer.DIRECTION_ALL }],
					[Hammer.Tap]
				]
			});

			self._hammer.set({ touchAction: 'none' });

			
			// when pan starts
			self._hammer.on("panstart", function(ev) {
				if( ! panstarted) {
				
					panstarted = true;
					self._currentx 	= slider.position().left;
				}
			});

			
			// do the pan
			self._hammer.on("panleft panright", function(ev) {
				if(panstarted){
					slider.slidexy(self._currentx + ev.deltaX, 0, true, false);
				}
			});

			
			// when pan ended
			self._hammer.on("panend", function(ev) {
				
				if(panstarted) {
					var newx = self._currentx + ev.deltaX;
					
					
					if(self._minx > 0) {
						
						var maxx = self.wrapper.width() - self._stripwidth;
						
						if (newx < 0) {
							// too much to the left
							slider.slidexy(0, 0, true, true,0.3);
							self._currentx = 0;
						} else if (newx > maxx){
							slider.slidexy(maxx, 0, true, true,0.3);
							self._currentx = maxx;
						} else {
						
							self._currentx = newx;
							panstarted = false;
						}


					} else {
						if (newx < self._minx) {
							// too much to the left
							slider.slidexy(self._minx, 0, true, true,0.3);
							self._currentx = self._minx;
						} else if (newx > 0) {
							// too much to the right
							slider.slidexy(0, 0, true, true,0.3);
							self._currentx = 0;
						} else {
							self._currentx = newx;
							panstarted = false;
						}
					}

					slider.one(self._transitionEnd, function(e) {
						panstarted = false;
					});	
				}
			});


			self._hammer.on("tap", function(ev) {
				var seqno = $(ev.target).data('seqno');
				if($(ev.target).hasClass('ip-thumbwrapper') && seqno != self._currentthumb && ! busy) {

					if( ! panstarted) {
							busy = true;
							self._el.container.removeClass("cursor-idle").addClass("cursor-busy");
							$(document).trigger("navigateto.ip",seqno);
						}
			
				}
			});
			
			// handle resize window event
			$( document ).on('ipresized', (function(e) {

				if(self._minx > 0) {
					slider.slidexy(0,0,true,true);
					self._currentx = self._minx;
					self._minx = self._getminx();
				} else {
					self._minx = self._getminx();
					if(self._currentx <= self._minx) {
						
						slider.slidexy(self._minx,0,true,true);
						self._currentx = self._minx;
					}
				}
				self._moveintoview(self._currentthumb, true);
			}));
			
			$(".ip-thumbimage").on('mousedown', function(e) {
				e.preventDefault();
				// to prevent dragging in Firefox
				return;
			});
			$(".ip-thumbimage").on('mouseover', function(e) {
				// to prevent dragging in Firefox
				return;
			});			
			self._el.container.on('wheel.ip', function(e) {
				var delta;
				
				if(self._minx > 0) {
					delta = Math.max(0, Math.min(self._minx , self._currentx + -1*2*e.originalEvent.deltaY));
					
				} else {
					delta = Math.max(self._minx, Math.min(0 , self._currentx + -1*2*e.originalEvent.deltaY));
				}
				slider.slidexy(delta, 0, true, true);
				self._currentx = delta;

				return false; 
			});
			$(document).on('navigatecompleted.ip', function(e) {
				self._el.container.removeClass("cursor-busy").addClass("cursor-idle");
				busy = false;

			});
			$(document).on('currentchange.ip', function(e, current) {
				self._setcurrent(current);
				self._moveintoview(current);
			});
			
			$("#ip-thumbstrip-toggle").on('click.ip', function(e) {

				self.toggle();
			});
			
		},
		toggle : function(hide) {
			
			var self = this;

			if(self._visible)  {
					
					self.off();
				}else {
					self.on();
					
					self._moveintoview(self._currentthumb,true);
			}
			$(window).trigger('doipresize');
			
		},
		off: function() {
			var self = this;
			if(self._visible && self._el.container) {
				self._visible = false;
				self._el.container.slidexy(0, self._thumbheight+2*self._thumbmargin, true, true, .4);
				$(self._el.toggler).removeClass('ip-thumbstrip-visible').addClass('ip-thumbstrip-hidden');
			}
		},
		on: function() {
			var self = this;
			if(! self._visible && self._el.container) {
				self._visible = true;
				self._el.container.slidexy(0, 0, true, true, .4);
				$(self._el.toggler).addClass('ip-thumbstrip-visible').removeClass('ip-thumbstrip-hidden');
			}
		},		
		hide: function() {
			var self = this;

			if( ! self._visible) {return;}

			self._temphide = true;
			self.toggle();
			
		},
		unhide: function() {
			var self = this;

			if( ! self._temphide) {return;}

			self._temphide = false;
			self.toggle();			
		},
		_setcurrent : function (seqno) {
			var self = this;

			if(seqno != self._currentthumb) {
					$("#thumbwrapper-"+self._currentthumb).removeClass("ip-thumb-current");
					$("#thumbwrapper-"+seqno).addClass("ip-thumb-current");
					
					self._currentthumb = seqno;
			
			}			
		},
		_moveintoview : function(seqno, initsetup) {
			var self 		= this;
			var overflow 	= -1 * self._getminx();
			var winw 		= self.wrapper.width();
			var itempos 	= (seqno) * (self._thumbwidth + 2 * self._thumbmargin);
			var itemw 		= self._thumbwidth + self._thumbmargin;
			var delta, newcurrentx;

			if( ! self._visible) return;
			
			// thumbstrip is narrower than window
			if (self.wrapper.width() >= self._stripwidth) {
				if(typeof initsetup != 'undefined') {
					 newcurrentx = Math.round(self.wrapper.width() - self._stripwidth) / 2;
					 slideit();
				}
				return;
			}else 

			// item is already inside window
			if(itempos + self._currentx >= 0 && itempos + self._currentx + itemw <= winw)
			{
				return;
			}

			if(itempos + self._currentx  + itemw > winw)
			{	// item is outside right window edge
				delta = itempos + self._currentx  + itemw - winw;
				if (self._stripwidth - itempos < winw){
						// we can move it to the end
						newcurrentx = self._getminx();
					}
					else {
						// otherwise just make sure that the item is visible
						newcurrentx = -1*(itempos - winw + itemw);
					}

			}else if (itempos + self._currentx < 0) {
				// item is outside left window edge 
				delta = -1 * (itempos);
				newcurrentx =  delta;
			} else {
				return;
			}
			slideit();

			
			function slideit() {
				var slidetime = Math.min(0.5,Math.max(0.2, Math.abs(Math.abs(newcurrentx) - Math.abs(self._currentx))* 0.2/500));

				self._currentx = newcurrentx;
				self._el.innerwrap.slidexy( self._currentx, 0, true, true, slidetime);				
			}
		}
	};

    $.fn[pluginName] = function ( options ) {
		return (new Plugin( this, options ));

    };
})( jQuery);